lair
====

**lair** is a small lightweight helper to create eggs
for flask based microservices.

.. image:: https://coveralls.io/repos/github/yitsushi/lair/badge.svg?branch=master
   :target: https://coveralls.io/github/yitsushi/lair?branch=master
.. image:: https://travis-ci.org/yitsushi/lair.svg?branch=master
   :target: https://travis-ci.org/yitsushi/lair
.. image:: https://readthedocs.org/projects/lair/badge/?version=latest
   :target: https://lair.readthedocs.io
